@@ -1,12 +1,7 @@
-/****************************************************************************
-
- KHotKeys
-
- Copyright (C) 2003 Lubos Lunak <l.lunak@kde.org>
-
- Distributed under the terms of the GNU General Public License version 2.
-
-****************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-only
+    SPDX-FileCopyrightText: 2003 Lubos Lunak <l.lunak@kde.org>
+ */
 
 #ifndef WINDOWSELECTOR_H
 #define WINDOWSELECTOR_H
